@@ -16,7 +16,8 @@ if (use_saved_results) {
 }
 
 ## ---- eval=TRUE---------------------------------------------------------------
-library(tidyverse) # Data wrangling
+library(dplyr); library(tidyr); library(purrr) # Data wrangling
+library(ggplot2); library(stringr) # Plotting
 library(tidyfit)   # Auto-ML modeling
 
 ## ---- eval=TRUE---------------------------------------------------------------
@@ -86,11 +87,11 @@ model_frame %>%
 ## ---- echo = F, eval=TRUE-----------------------------------------------------
 library(kableExtra)
 tbl <- data.frame(
-  `Best subset` = c("Exhaustive search (`leaps`)", "Forward selection (`leaps`)", "Backward selection (`leaps`)", "Sequential Replacement (`leaps`)"),
-  `L1/L2 penalized` = c("Lasso (`glmnet`)", "Ridge (`glmnet`)", "ElasticNet (`glmnet`)", "Adaptive Lasso (`glmnet`)"),
-  `Latent factors` = c("Principal components regression (`pls`)", "Partial least squares (`pls`)", "", ""),
-  `Machine Learning` = c("Gradient Boosting (`mboost`)", "Hierarchical feature regression (`hfr`)", "Support vector regression (`e1071`)", ""),
-  `Bayesian` = c("Bayesian regression (`arm`)", "Bayesian model averaging (`BMS`)", "", ""),
+  `Best subset` = c("Exhaustive search (`leaps`)", "Forward selection (`leaps`)", "Backward selection (`leaps`)", "Sequential Replacement (`leaps`)", "Genetic Algorithm ('gaselect')"),
+  `L1/L2 penalized` = c("Lasso (`glmnet`)", "Ridge (`glmnet`)", "ElasticNet (`glmnet`)", "Adaptive Lasso (`glmnet`)", ""),
+  `Latent factors` = c("Principal components regression (`pls`)", "Partial least squares (`pls`)", "", "", ""),
+  `Machine Learning` = c("Gradient Boosting (`mboost`)", "Hierarchical feature regression (`hfr`)", "Support vector regression (`e1071`)", "", ""),
+  `Bayesian` = c("Bayesian regression (`arm`)", "Bayesian model averaging (`BMS`)", "Bayesian Lasso (`monomvn`)", "Bayesian Ridge (`monomvn`)", "Spike and Slab Regression ('BoomSpikeSlab')"),
   check.names = F
 )
 kbl(tbl, align = "ccccc") %>% 
@@ -102,12 +103,15 @@ kbl(tbl, align = "ccccc") %>%
 #    regress(medv ~ .*.,
 #            OLS = m("lm"),
 #            BAYES = m("bayes"),
-#            BMA = m("bma", iter = 5000),
+#            BMA = m("bma", iter = 10000),
 #            SEQREP = m("subset", method = "seqrep", IC = "AIC"),
 #            `FORWARD SELECTION` = m("subset", method = "forward", IC = "AIC"),
 #            `BACKWARD SELECTION` = m("subset", method = "backward", IC = "AIC"),
 #            LASSO = m("lasso"),
+#            BLASSO = m("blasso"),
+#            SPIKESLAB = m("spikeslab", niter = 10000),
 #            RIDGE = m("ridge"),
+#            BRIDGE = m("bridge"),
 #            ELASTICNET = m("enet"),
 #            ADALASSO = m("adalasso", lambda_ridge = c(0.001, 0.01, 0.1)),
 #            PCR = m("pcr"),
@@ -115,6 +119,7 @@ kbl(tbl, align = "ccccc") %>%
 #            HFR = m("hfr"),
 #            `GRADIENT BOOSTING` = m("boost"),
 #            SVR = m("svm"),
+#            GENETIC = m("genetic", populationSize = 1000, numGenerations = 50, statistic = "AIC", maxVariables = 20),
 #            .cv = "vfold_cv", .cv_args = list(v = 10))
 
 ## -----------------------------------------------------------------------------
